#
# spec file for package cmocka
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           cmocka
Version:        1.1.1
Release:        lp150.1.15
Summary:        Lightweight library to simplify and generalize unit tests for C
License:        Apache-2.0
Group:          Productivity/Networking/Other
Url:            http://cmocka.org
Source0:        https://cmocka.org/files/1.1/%{name}-%{version}.tar.xz
Source1:        baselibs.conf
BuildRequires:  cmake
BuildRequires:  glibc-devel
BuildRequires:  pkg-config
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
cmocka is an elegant unit testing framework for C with support for mock
objects. It only requires the standard C library, works on a range of computing
platforms (including embedded) and with different compilers.

Features:
  * Support for mock objects
  * Only requires the C library
  * Several supported output formats (Subunit, TAP, jUnit XML)
  * Fully documented API
  * Test fixtures
  * Exception handling for signals (SIGSEGV, SIGILL, ...)
  * No fork() used
  * Very well tested
  * Testing of memory leaks, buffer overflows and underflows.

Also, CMocka tries to avoid the use of some of the newer features of C
compilers.

%package -n libcmocka0
Summary:        Lightweight library to simplify and generalize unit tests for C
Group:          System/Libraries

%description -n libcmocka0
cmocka is an elegant unit testing framework for C with support for mock
objects. It only requires the standard C library, works on a range of computing
platforms (including embedded) and with different compilers.

Features:
  * Support for mock objects
  * Only requires the C library
  * Several supported output formats (Subunit, TAP, jUnit XML)
  * Fully documented API
  * Test fixtures
  * Exception handling for signals (SIGSEGV, SIGILL, ...)
  * No fork() used
  * Very well tested
  * Testing of memory leaks, buffer overflows and underflows.

Also, CMocka tries to avoid the use of some of the newer features of C
compilers.

%package -n libcmocka-devel
Summary:        Development headers for the cmocka library
Group:          Development/Libraries/C and C++
Requires:       cmake
Requires:       libcmocka0 = %{version}
Requires:       pkg-config

%description -n libcmocka-devel
Development headers for the cmocka unit testing library.

%package -n libcmocka-devel-static
Summary:        Static cmocka library
Group:          Development/Libraries/C and C++
Requires:       libcmocka-devel = %{version}

%description -n libcmocka-devel-static
Static cmocka unit testing library.

%prep
%setup -q

%build
%cmake \
    -DCMAKE_SKIP_RPATH=OFF \
    -DWITH_STATIC_LIB=ON \
    -DWITH_CMOCKERY_SUPPORT=ON \
    -DUNIT_TESTING=ON

make %{?_smp_mflags}

%install
%cmake_install

%check
pushd build
make %{?_smp_mflags} test || {
    cat Testing/Temporary/LastTest.log;
    exit 1;
}
popd

%post -n libcmocka0 -p /sbin/ldconfig

%postun -n libcmocka0 -p /sbin/ldconfig

%files -n libcmocka0
%defattr(-,root,root)
%doc AUTHORS README ChangeLog COPYING
%{_libdir}/libcmocka.so.*

%files -n libcmocka-devel
%defattr(-,root,root)
%{_includedir}/cmocka.h
%{_includedir}/cmocka_pbc.h
%dir %{_includedir}/cmockery
%{_includedir}/cmockery/cmockery.h
%{_includedir}/cmockery/pbc.h
%{_libdir}/libcmocka.so
%{_libdir}/pkgconfig/cmocka.pc
%dir %{_libdir}/cmake/cmocka
%{_libdir}/cmake/cmocka/cmocka-config-version.cmake
%{_libdir}/cmake/cmocka/cmocka-config.cmake

%files -n libcmocka-devel-static
%defattr(-,root,root)
%{_libdir}/libcmocka.a

%changelog
* Fri Apr  7 2017 asn@cryptomilk.org
- Update to version 1.1.1
  * Fixed TAP output
  * Fixed cmocka on Windows x64
  * Fixed xUnit output durations
* Tue Oct 25 2016 asn@cryptomilk.org
- Fix url for Source0
* Wed Sep 21 2016 asn@cryptomilk.org
- Update to version 1.1.0
  * Added support to catch multiple exceptions
  * Added support to verify call ordering
  * Added support to pass initial data to test cases
  * Added will_return_maybe() for ignoring mock returns
  * Added subtests for groups using TAP output
  * Added support to write multiple XML files for groups
  * Improved documentation
  * Fixed XML output generataion
  * Fixed Windows builds with VS2015
* Wed Jul 15 2015 asn@cryptomilk.org
- Do not turn of rpath support
* Tue Jul 14 2015 tchvatal@suse.com
- Use properly %%cmake macro to build nicely with all the linker/cflags
- Use proper Url and Source
- Properly fails on crashing tests instead of finishing build
- Enable cmockery support
* Thu Mar 12 2015 asn@cryptomilk.org
- Update to version 1.0.1
  * Added a macro for assert_ptr_equal().
  * Fixed test_realloc() if 0 size is passed.
  * Fixed objects packaging bug.
  * Fixed building with newer gcc versions.
* Tue Feb 17 2015 asn@cryptomilk.org
- Add missing requires for cmake and pkg-config
* Tue Feb 17 2015 asn@cryptomilk.org
- Turn on unit tests
* Mon Feb 16 2015 asn@cryptomilk.org
- Update to version 1.0.0
  * Added new test runner with group fixtures. The old runner is deprecated
  * Added an extensible message output formatter
  * Added jUnit XML message output
  * Added subunit message output
  * Added Test Anything Protocol message output
  * Added skip() command
  * Added test_realloc()
  * Added a cmockery compat header
  * Fixed a lot of bugs on Windows
* Thu Sep 11 2014 asn@cryptomilk.org
- Update to version 0.4.1
  * Added CMOCKA_TEST_ABORT env variable to leave threading apps.
  * Fixed count parameter of expect_check() macro.
  * Fixed reporting the number of tests.
  * Fixed cmake config files.
* Mon Sep  1 2014 asn@cryptomilk.org
- Add baselibs.conf as Source.
* Tue Aug 26 2014 asn@cryptomilk.org
- Add BuildRequire for pkg-config.
* Tue Aug 26 2014 asn@cryptomilk.org
- Add BuildRequire for pkg-config.
* Fri Apr 11 2014 asn@cryptomilk.org
- Update to version 0.4.0
  * Added support for group testing.
  * Added assert_return_code().
  * Added better messages for errors.
  * Added cmake config mode support.
  * Fixed bug with unit_test_setup and unit_test_teardown.
  * Fixed a lot of small bugs.
* Mon Nov 11 2013 asn@cryptomilk.org
- Update to version 0.3.2
  * Fixed FindNSIS detection.
  * Fixed unit_test_setup() and unit_test_teardown().
  * Fixed GTest and GCC message style conformance
  * Fixed stringification in will_return_always().
* Wed Jul 10 2013 asn@cryptomilk.org
- Update to version 0.3.1
  * Fixed pointer conversion on s390 and ppc (32bit big endian).
  * Fixed the customer_database test on big endian.
* Wed Jun  5 2013 asn@cryptomilk.org
- Update to version 0.3.0
  * Added a better mock object example.
  * Added pkgconfig file.
  * Added new macros mock_type() and mock_ptr_type().
  * Added more documentation.
  * Fixed installation problems on some platforms.
* Tue Feb  5 2013 asn@cryptomilk.org
- Add a libcmocka-devel-static package for the static library.
* Mon Jan 14 2013 asn@cryptomilk.org
- Uploaded release tarball.
* Wed Oct 10 2012 asn@cryptomilk.org
- Fix building i686 on a x86_64 platform.
* Tue Jun 26 2012 asn@cryptomilk.org
- Initial version 0.2.0
